pub struct SqliteEnvelopeStackConfig {
pub partition_id: u8,
pub batch_size_bytes: usize,
pub flush_timeout: Option<Duration>,
pub unspool_throttle: Option<Arc<Throttle>>,
}Expand description
Configuration for a SqliteEnvelopeStack.
Fields
partition_id: u8The partition of the envelope buffer to which the stack belongs.
batch_size_bytes: usizeMaximum number of bytes in the in-memory cache before writing to disk.
flush_timeout: Option<Duration>Time after which to flush the buffer to disk.
unspool_throttle: Option<Arc<Throttle>>Optional throttle which paces how quickly envelopes are unspooled from disk.